<?php

namespace App\Gateway;

use App\Connexion;
use PDO;

class TeamGateway {
    private Connexion $con;

    public function __construct(Connexion $con) {
        $this->con = $con;
    }

    public function insert(string $name, string $picture, int $mainColor, int $secondColor) {
        $this->con->exec(
            "INSERT INTO Team(name, picture, mainColor, secondColor) VALUES (:teamName , :picture, :mainColor, :secondColor)",
            [
                ":teamName" => [$name, PDO::PARAM_STR],
                ":picture" => [$picture, PDO::PARAM_STR],
                ":mainColor" => [$mainColor, PDO::PARAM_INT],
                ":secondColor" => [$secondColor, PDO::PARAM_INT]
            ]
        );
    }

    public function listByName(string $name): array {
        return $this->con->fetch(
            "SELECT id,name,picture,mainColor,secondColor FROM Team WHERE name LIKE '%' || :name || '%'",
            [
                ":name" => [$name, PDO::PARAM_STR]
            ]
        );
    }

    public function getTeamById(int $id): array{
        return $this->con->fetch(
            "SELECT name,picture,mainColor,secondColor FROM Team WHERE id = :id",
            [
                ":id" => [$id, PDO::PARAM_INT]
            ]
        );
    }

    public function getMembersById($id):array{
        return $this->con->fetch(
          "SELECT p.role,m.email FROM Member m,Team t,Participate p WHERE t.id = :id AND p.idTeam = t.id AND p.idMember = m.id",
          [
              ":id" => [$id, PDO::PARAM_INT]
          ]
        );
    }

}